@@ -29,14 +29,4 @@ def evalRPoly(roots, x, k=1):
 	for r in roots:
 		y = y*(x - r)
 	return y
-	
-def test_evalRPoly():
-	"""Test function for evalRPoly()
-	"""
-	x = np.arange(1001) - 500
-	a = [1, 0, 1, 2]
-	r1 = np.polyval(a, x)
-	rts = np.roots(a)
-	r2 = evalRPoly(rts, x)
-	assert np.allclose(r1, r2, atol=1e-8, rtol=1e-5)
 
