@@ -51,21 +51,4 @@ def padb(x, n, val=0.):
                         val*np.ones((n - xp.shape[0], xp.shape[1]))
                        ), axis=0)
     return y
-                      
-def test_padb():
-    """Test function for padb()"""
-    # regular matrix
-    tv = np.eye(15)
-    tr = padb(tv, n=25, val=2)
-    res = np.concatenate((tv, 2.*np.ones((10, 15))), axis=0)
-    assert np.allclose(tr, res, atol=1e-8, rtol=1e-5)
-    # 1-d array
-    tv = np.arange(10)
-    tr = padb(tv, n=25, val=1.5)
-    res = np.vstack((tv.reshape((-1, 1)), 1.5*np.ones((15, 1))))
-    assert np.allclose(tr, res, atol=1e-8, rtol=1e-5)
-    # empty matrix array
-    tv = np.array([])
-    tr = padb(tv, n=25, val=1.5)
-    res = np.vstack((tv.reshape((-1, 1)), 1.5*np.ones((25, 1))))
-    assert np.allclose(tr, res, atol=1e-8, rtol=1e-5)
+
